# pyepic
[![Documentation Status](https://readthedocs.org/projects/pyepic/badge/?version=latest)](http://pyepic.readthedocs.io/?badge=latest) [![PyPI version fury.io](https://badge.fury.io/py/pyepic.svg)](https://pypi.python.org/pypi/pyepic/)

PyEpic is a simple Python SDK for the EPIC API code. It is designed to allow users to integrate with EPIC for the submission and management of HPC jobs. It can be used directly or an an example of how to make use of the [epiccore](https://github.com/zenotech/python_epic_api) package.

## Getting started
PyEpic can be installed from PyPi.

```
pip install pyepic
```

Documentation is available on [read the docs](http://pyepic.readthedocs.io/?badge=latest).
